@@ -46,6 +46,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_Qt3DLogicTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_Qt3DLogicTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_Qt3DLogicModuleObject;
 
@@ -55,23 +58,21 @@ extern SbkConverter **SbkPySide6_Qt3DLogicTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QT3DLOGIC_QLIST_INT_IDX                              = 0, // QList<int>
-    SBK_QT3DLOGIC_QLIST_QT3DCORE_QENTITYPTR_IDX              = 2, // QList<Qt3DCore::QEntity*>
-    SBK_QT3DLOGIC_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX = 4, // std::vector<QSharedPointer< Qt3DCore::QAspectJob>>
-    SBK_QT3DLOGIC_QLIST_QVARIANT_IDX                         = 6, // QList<QVariant>
-    SBK_QT3DLOGIC_QLIST_QSTRING_IDX                          = 8, // QList<QString>
-    SBK_QT3DLOGIC_QMAP_QSTRING_QVARIANT_IDX                  = 10, // QMap<QString,QVariant>
-    SBK_QT3DLOGIC_CONVERTERS_IDX_COUNT                       = 12,
+    SBK_QT3DLOGIC_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX = 2, // std::vector<QSharedPointer<Qt3DCore::QAspectJob>>
+    SBK_QT3DLOGIC_QLIST_QVARIANT_IDX                         = 4, // QList<QVariant>
+    SBK_QT3DLOGIC_QLIST_QSTRING_IDX                          = 6, // QList<QString>
+    SBK_QT3DLOGIC_QMAP_QSTRING_QVARIANT_IDX                  = 8, // QMap<QString,QVariant>
+    SBK_QT3DLOGIC_CONVERTERS_IDX_COUNT                       = 10,
 };
 
 // Converter indices
 enum : int {
     SBK_Qt3DLogic_QList_int_IDX                              = 0, // QList<int>
-    SBK_Qt3DLogic_QList_Qt3DCore_QEntityPTR_IDX              = 1, // QList<Qt3DCore::QEntity*>
-    SBK_Qt3DLogic_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX = 2, // std::vector<QSharedPointer< Qt3DCore::QAspectJob>>
-    SBK_Qt3DLogic_QList_QVariant_IDX                         = 3, // QList<QVariant>
-    SBK_Qt3DLogic_QList_QString_IDX                          = 4, // QList<QString>
-    SBK_Qt3DLogic_QMap_QString_QVariant_IDX                  = 5, // QMap<QString,QVariant>
-    SBK_Qt3DLogic_CONVERTERS_IDX_COUNT                       = 6,
+    SBK_Qt3DLogic_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX = 1, // std::vector<QSharedPointer<Qt3DCore::QAspectJob>>
+    SBK_Qt3DLogic_QList_QVariant_IDX                         = 2, // QList<QVariant>
+    SBK_Qt3DLogic_QList_QString_IDX                          = 3, // QList<QString>
+    SBK_Qt3DLogic_QMap_QString_QVariant_IDX                  = 4, // QMap<QString,QVariant>
+    SBK_Qt3DLogic_CONVERTERS_IDX_COUNT                       = 5,
 };
 // Macros for type check
 
